@@ -953,6 +953,46 @@ def check_performance(*, registry: InstallationCheckRegistry,
         return (Status.OK, "")
 
 
+def overridable_resources(*, registry: InstallationCheckRegistry):
+    """
+    Ensure that resources are overridable for Platform workers.
+
+    registry : The InstallationCheckRegistry
+        The registry used to run this check.
+
+    Returns
+    -------
+    tuple
+        Status
+            The status of the check as OK, WARNING, ERROR or CRITICAL.
+        str
+            A message to display about the WARNING, ERROR or CRITICAL result.
+    """
+    # Create a trainee and acquire its resources.
+    try:
+        if engine:
+            with engine.Trainee(
+                name=f"installation_verification overridable resources ({get_nonce()})",
+                persistence="never",
+                runtime={"scaling": {"resources": {"cpu": {"minimum": 1_500}}}},
+            ) as trainee:
+                runtime = trainee.get_runtime()
+                try:
+                    if runtime["scaling"]["resources"]["cpu"]["minimum"] != 1_500:  # type: ignore
+                        raise AssertionError("Incorrect value returned")
+                except (KeyError, TypeError, ValueError):
+                    traceback.print_exc(file=registry.logger)
+                    return (Status.CRITICAL, "get_runtime() returned an unexpected response.")
+                except AssertionError:
+                    traceback.print_exc(file=registry.logger)
+                    return (Status.CRITICAL, "get_runtime() returned an unexpected value for minimum CPU cores.")
+                else:
+                    return (Status.OK, "")
+    except Exception:
+        traceback.print_exc(file=registry.logger)
+        return (Status.CRITICAL, "Could not create a trainee.")
+
+
 def check_engine_operation(
     *,
     registry: InstallationCheckRegistry,
@@ -1189,6 +1229,12 @@ def configure(registry: InstallationCheckRegistry):
         client_required="HowsoPlatformClient",
     )
 
+    registry.add_check(
+        name="Howso Client: Overridable resources",
+        fn=partial(overridable_resources),
+        client_required="HowsoPlatformClient",
+    )
+
     registry.add_check(
         name="Howso Local: System performance",
         fn=partial(check_performance, num_samples=5_000,
